  if (!require(shiny)) {install.packages('shiny')}
  library(shiny)
  if (!require(shinythemes)) {install.packages('shinythemes')}
  library(shinythemes)
  
  ui <- fluidPage(theme=shinytheme("flatly"),
                   titlePanel("P-value distribution for t-test"),
                   sidebarLayout(
                      sidebarPanel(numericInput("N", "Participants per group:", 50, min = 1, max = 1000),
                                   sliderInput("d", label = HTML("Cohen's d (&delta;)"), min = 0, max = 2, value = 0.5, step= 0.01),
                                   sliderInput("p_upper", "p-value (upper limit):", min = 0, max = 1, value = 1, step= 0.005),
                                   numericInput("bars", "Number of bars in plot:", 100, min = 1, max = 10000), 
                                   numericInput("y_max", "Maximum on y-axis:", 10000, min = 1, max = 10000), 
                                   width = 3,
                                   br()
                     ),
                      mainPanel(
                        plotOutput("plot_p")
                     )
                   )
  )
  server <- function(input, output) {
    #surpress warnings
    options(warn = -1)
    output$plot_p <- renderPlot({
      N<-input$N
      #mean IQ in population 100, std 15
      IQ<-input$d*15+100
      p_upper<-input$p_upper
      p_low<-0
      bars<-input$bars
      y_max<-input$y_max
      nSims <- 10000 #number of simulated experiments
      p <-numeric(nSims) #set up empty variable to store all simulated p-values
      #Run simulation
      for(i in 1:nSims){ #for each simulated experiment
        x<-rnorm(n = N, mean = IQ, sd = 15) #Simulate data with specified mean, standard deviation, and sample size
        z<-t.test(x, mu=100) #perform the t-test against mu (set to value you want to test against)
        p[i]<-z$p.value #get the p-value and store it
      }
      power<-pwr.t.test(d=input$d, n=N,sig.level=0.05,type="one.sample",alternative="two.sided")$power
      hist(p, breaks=bars, xlab="P-values", ylab="number of p-values\n", axes=FALSE,
           main=paste("P-value Distribution with",round(power*100, digits=1),"% Power"),
           col="grey", xlim=c(p_low,p_upper), ylim=c(0, y_max))
      axis(side=1, at=seq(p_low, p_upper, (p_upper-p_low)/10), labels=seq(p_low,p_upper,(p_upper-p_low)/10))
      axis(side=2, at=seq(0,y_max, y_max/4), labels=seq(0,y_max, y_max/4), las=2)
      abline(h=nSims/bars, col = "red", lty=3)
    })
  }
  shinyApp(ui = ui, server = server)
  
  # Daniel Lakens, 2019. 
  # This work is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. https://creativecommons.org/licenses/by-nc-sa/4.0/